Contributing to xmldiff
=======================

xmldiff is a library and a command line utility for making diffs out of
XML and XML derived formats, such as XHTML.


Setting up a dev environment
----------------------------


Testing
-------


Pull requests
-------------


Code quality
------------


Implementation details
----------------------

xmldiff is based on `"Change Detection in Hierarchically StructuredS Information"`<http://ilpubs.stanford.edu/115/1/1995-46.pdf>
by Sudarshan S. Chawathe, Anand Rajaraman, Hector Garcia-Molina, and
Jennifer Widom, 1995. It's not necessary to read and understand that
paper in all it's details to help with xmldiff, but if you want to
improve the actual diffing algorithm it is certainly helpful.
